import * as i0 from '@angular/core';
import { Injectable, forwardRef, EventEmitter, Component, ViewEncapsulation, Input, Output, NgModule, CUSTOM_ELEMENTS_SCHEMA, NO_ERRORS_SCHEMA } from '@angular/core';
import * as i2 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2$1 from '@angular/forms';
import { NG_VALUE_ACCESSOR, FormsModule } from '@angular/forms';
import moment from 'moment';
import { InputCoreComponent } from '@sq-ui/ng-sq-common';
import { List } from 'immutable';

var CalendarPeriodRelativityEnum;
(function (CalendarPeriodRelativityEnum) {
    CalendarPeriodRelativityEnum[CalendarPeriodRelativityEnum["Current"] = 0] = "Current";
    CalendarPeriodRelativityEnum[CalendarPeriodRelativityEnum["Before"] = 1] = "Before";
    CalendarPeriodRelativityEnum[CalendarPeriodRelativityEnum["After"] = 2] = "After";
})(CalendarPeriodRelativityEnum || (CalendarPeriodRelativityEnum = {}));

class CalendarManagerService {
    constructor() {
        this.locale = 'en';
        this.previouslySelectedYear = moment();
    }
    setLocale(locale) {
        moment.locale(locale);
        this.locale = locale;
    }
    generateCalendarForMonth(startDate, currentMonth, selectedDates, dateRange) {
        const monthStart = moment(startDate).startOf('month').locale(this.locale);
        const isStartOfChosenMonthTheFirstDayOfTable = (monthStart.weekday() === 0);
        const dateIterator = monthStart.clone();
        const calendar = [];
        let tableRow = [];
        let newDate;
        if (!isStartOfChosenMonthTheFirstDayOfTable) {
            let daysToGoBack = dateIterator.weekday();
            daysToGoBack = (daysToGoBack === 0) ? 1 : daysToGoBack;
            dateIterator.subtract(daysToGoBack, 'days');
        }
        // add dates until the calendar has 6 week rows
        while (calendar.length < 6) {
            newDate = {
                displayDate: dateIterator.format('D'),
                momentObj: dateIterator.clone(),
                relativityToCurrentMonth: this.determineDateRelativityToCurrentMonth(dateIterator, currentMonth),
                isDisabled: this.determineIfDateIsDisabled(dateIterator, dateRange.minDate, dateRange.maxDate),
                isSelected: this.getSelectedItemIndex(dateIterator, selectedDates) > -1
            };
            if (tableRow.length <= 6) {
                tableRow.push(newDate);
            }
            else {
                calendar.push(tableRow);
                tableRow = [newDate];
            }
            dateIterator.add(1, 'day');
        }
        return calendar;
    }
    generateMonthPickerCollection(currentYear, dateRange) {
        const months = this.getMonths();
        return months.map((monthName, index) => {
            const date = moment().year(currentYear).month(index);
            return {
                displayName: monthName,
                momentObj: date,
                isDisabled: this.determineIfDateIsDisabled(date, dateRange.minDate, dateRange.maxDate)
            };
        });
    }
    generateYearPickerCollection(start, margin = 19, dateRange) {
        const yearsList = this.getYearList(start, margin);
        return yearsList.map((year) => {
            const date = moment().year(year);
            return {
                displayName: year.toString(),
                momentObj: date,
                isDisabled: this.determineIfDateIsDisabled(date, dateRange.minDate, dateRange.maxDate)
            };
        });
    }
    getWeekdays(short = true) {
        return short ? moment.weekdaysShort(true) : moment.weekdays(true);
    }
    getMonths(short = true) {
        return short ? moment.monthsShort() : moment.months();
    }
    getYearList(start, margin = 19) {
        let yearIterator;
        let endYear;
        if (start) {
            this.previouslySelectedYear = start.clone();
        }
        if (margin < 0) {
            endYear = moment(this.previouslySelectedYear).add(margin, 'years');
            yearIterator = moment(endYear).add(margin, 'years');
        }
        else {
            yearIterator = moment(this.previouslySelectedYear);
            endYear = moment(yearIterator).add(margin, 'years');
        }
        const yearList = [];
        while (yearIterator.isSameOrBefore(endYear)) {
            yearList.push(yearIterator.clone().year());
            yearIterator.add(1, 'year');
        }
        this.previouslySelectedYear = yearIterator.subtract(1, 'year').clone();
        return yearList;
    }
    findADateFromCalendar(date, calendarTable) {
        const dateToFind = moment(date);
        const flatCalendarTable = calendarTable.reduce((acc, val) => acc.concat(val), []);
        return flatCalendarTable.find((calendarDay) => {
            return calendarDay.momentObj.isSame(dateToFind, 'day');
        });
    }
    getSelectedItemIndex(date, selectedDates) {
        return selectedDates.findIndex((selectedDate) => {
            return moment(selectedDate).isSame(date, 'day');
        });
    }
    determineIfDateIsDisabled(currentDate, minDate, maxDate) {
        const isAfterMaxDate = maxDate && moment(currentDate).isAfter(maxDate, 'day');
        const isBeforeMinDate = minDate && moment(currentDate).isBefore(minDate, 'day');
        return (isAfterMaxDate || isBeforeMinDate);
    }
    determineDateRelativityToCurrentMonth(date, currentMonth) {
        const startOfCurrentMonth = moment(currentMonth).startOf('month');
        const endOfCurrentMonth = moment(currentMonth).endOf('month');
        if (moment(date).isBefore(startOfCurrentMonth)) {
            return CalendarPeriodRelativityEnum.Before;
        }
        if (moment(date).isAfter(endOfCurrentMonth)) {
            return CalendarPeriodRelativityEnum.After;
        }
        return CalendarPeriodRelativityEnum.Current;
    }
    sortDatesAsc(dates) {
        return dates.sort((date1, date2) => {
            if (moment(date1).isAfter(date2)) {
                return 1;
            }
            else {
                return -1;
            }
        });
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: CalendarManagerService, deps: [], target: i0.ɵɵFactoryTarget.Injectable }); }
    static { this.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: CalendarManagerService }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: CalendarManagerService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return []; } });

var CalendarPeriodTypeEnum;
(function (CalendarPeriodTypeEnum) {
    CalendarPeriodTypeEnum[CalendarPeriodTypeEnum["Month"] = 0] = "Month";
    CalendarPeriodTypeEnum[CalendarPeriodTypeEnum["Year"] = 1] = "Year";
})(CalendarPeriodTypeEnum || (CalendarPeriodTypeEnum = {}));

var DateObjectType;
(function (DateObjectType) {
    DateObjectType["Moment"] = "moment";
    DateObjectType["Date"] = "date";
    DateObjectType["Unix"] = "unix";
})(DateObjectType || (DateObjectType = {}));

var TimeUnit;
(function (TimeUnit) {
    TimeUnit["Hours"] = "hours";
    TimeUnit["Minutes"] = "minutes";
})(TimeUnit || (TimeUnit = {}));

var TimeObject;
(function (TimeObject) {
    TimeObject["String"] = "string";
    TimeObject["Moment"] = "moment";
})(TimeObject || (TimeObject = {}));

const CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR$1 = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => TimePickerComponent),
    multi: true,
};
class TimePickerComponent extends InputCoreComponent {
    constructor() {
        super();
        this.hourStep = 1;
        this.minuteStep = 1;
        this.isMeridiem = false;
        this.isEditable = true;
        this.timeObjectType = TimeObject.String;
        this.inputHoursChange = new EventEmitter();
        this.inputMinutesChange = new EventEmitter();
        this.noonRelativity = 'am';
        this.timeUnit = TimeUnit;
        this.start = moment();
        this.hourFormat = 'HH'; // 24-hour format by default
        this.limits = {
            hours: {
                min: 0,
                max: 24
            },
            minutes: {
                min: 0,
                max: 59
            }
        };
    }
    ngOnInit() {
        this.hours = this.start.format(this.hourFormat);
        this.minutes = this.start.format('mm');
        this.setValueResult();
    }
    ngOnChanges(changesObj) {
        if (changesObj.isMeridiem) {
            if (changesObj.isMeridiem.currentValue) {
                this.hourFormat = 'hh';
                this.noonRelativity = this.start.format('a');
                this.limits.hours.min = 1;
                this.limits.hours.max = 12;
            }
            else {
                this.hourFormat = 'HH';
                this.limits.hours.min = 0;
                this.limits.hours.max = 24;
            }
            this.hours = this.start.format(this.hourFormat);
        }
        if (changesObj.inputHours &&
            changesObj.inputHours.currentValue !== null &&
            typeof changesObj.inputHours.currentValue !== 'undefined' &&
            changesObj.inputHours.currentValue > -1) {
            this.hours = this.start.hours(changesObj.inputHours.currentValue).format(this.hourFormat);
            this.noonRelativity = this.start.format('a');
        }
        if (changesObj.inputMinutes &&
            changesObj.inputMinutes.currentValue !== null &&
            typeof changesObj.inputMinutes.currentValue !== 'undefined' &&
            changesObj.inputMinutes.currentValue > -1) {
            this.minutes = this.start.minutes(changesObj.inputMinutes.currentValue).format('mm');
        }
        this.setValueResult();
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.setValueResult();
        });
    }
    increment(unit) {
        switch (unit) {
            case TimeUnit.Hours:
                this.hours = this.start.add(this.hourStep, 'hours').format(this.hourFormat);
                this.inputHoursChange.emit(parseInt(this.hours, 10));
                break;
            case TimeUnit.Minutes:
                this.minutes = this.start.add(this.minuteStep, 'minutes').format('mm');
                this.inputMinutesChange.emit(parseInt(this.minutes, 10));
                break;
        }
        this.setValueResult();
    }
    decrement(unit) {
        switch (unit) {
            case TimeUnit.Hours:
                this.hours = this.start.subtract(this.hourStep, 'hours').format(this.hourFormat);
                this.inputHoursChange.emit(parseInt(this.hours, 10));
                break;
            case TimeUnit.Minutes:
                this.minutes = this.start.subtract(this.minuteStep, 'minutes').format('mm');
                this.inputMinutesChange.emit(parseInt(this.minutes, 10));
                break;
        }
        this.setValueResult();
    }
    changeNoonRelativity() {
        this.noonRelativity = this.noonRelativity === 'am' ? 'pm' : 'am';
        this.setValueResult();
    }
    validateInput(unit) {
        switch (unit) {
            case TimeUnit.Hours:
                this.hours = this.normalizeTimeInput(this.hours, TimeUnit.Hours);
                break;
            case TimeUnit.Minutes:
                this.minutes = this.normalizeTimeInput(this.minutes, TimeUnit.Minutes);
                break;
        }
        this.setValueResult();
    }
    normalizeTimeInput(value, unit) {
        if (!value) {
            value = '00';
        }
        if (parseInt(value, 10) >= this.limits[unit].max) {
            value = this.limits[unit].max.toString();
            if (unit === TimeUnit.Hours && !this.isMeridiem) {
                value = '00';
            }
        }
        if (parseInt(value, 10) < this.limits[unit].min) {
            value = this.limits[unit].min.toString();
        }
        return value;
    }
    setValueResult() {
        let timeMoment;
        let timeString = `${this.hours}:${this.minutes}`;
        timeString = this.isMeridiem ? `${timeString} ${this.noonRelativity.toUpperCase()}` : timeString;
        if (this.timeObjectType === TimeObject.Moment) {
            const momentFormat = this.isMeridiem ? 'hh:mm A' : 'HH:mm';
            timeMoment = moment(timeString, momentFormat);
        }
        this.value = timeMoment ? timeMoment : timeString;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: TimePickerComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.0.4", type: TimePickerComponent, selector: "sq-time-picker", inputs: { hourStep: "hourStep", minuteStep: "minuteStep", isMeridiem: "isMeridiem", isEditable: "isEditable", inputHours: ["hours", "inputHours"], inputMinutes: ["minutes", "inputMinutes"], timeObjectType: "timeObjectType" }, outputs: { inputHoursChange: "hoursChange", inputMinutesChange: "minutesChange" }, providers: [CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR$1], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<div class=\"time-picker display-flex justify-center align-items-center\">\r\n  <div class=\"time-unit display-flex column align-items-center\">\r\n    <button type=\"button\"\r\n            class=\"spinner display-flex justify-center align-items-center\"\r\n            (click)=\"increment(timeUnit.Hours)\">\r\n      <i class=\"fas fa-chevron-up\" aria-hidden=\"true\"></i>\r\n    </button>\r\n\r\n    <div class=\"time display-flex column align-items-center\">\r\n      <input type=\"text\"\r\n             name=\"time\"\r\n             [(ngModel)]=\"hours\"\r\n             maxlength=\"2\"\r\n             minlength=\"1\"\r\n             [disabled]=\"!isEditable\"\r\n             [ngModelOptions]=\"{standalone: true}\"\r\n             (ngModelChange)=\"validateInput(timeUnit.Hours)\">\r\n    </div>\r\n\r\n    <button type=\"button\"\r\n            class=\"spinner display-flex justify-center align-items-center\"\r\n            (click)=\"decrement(timeUnit.Hours)\">\r\n      <i class=\"fas fa-chevron-down\" aria-hidden=\"true\"></i>\r\n    </button>\r\n  </div>\r\n\r\n  <div class=\"time-unit divider\">:</div>\r\n\r\n  <div class=\"time-unit display-flex column align-items-center\">\r\n    <button type=\"button\"\r\n            class=\"spinner display-flex justify-center align-items-center\"\r\n            (click)=\"increment(timeUnit.Minutes)\">\r\n      <i class=\"fas fa-chevron-up\" aria-hidden=\"true\"></i>\r\n    </button>\r\n\r\n    <div class=\"time\">\r\n      <input type=\"text\"\r\n             name=\"minutes\"\r\n             [(ngModel)]=\"minutes\"\r\n             maxlength=\"2\"\r\n             minlength=\"1\"\r\n             [disabled]=\"!isEditable\"\r\n             [ngModelOptions]=\"{standalone: true}\"\r\n             (ngModelChange)=\"validateInput(timeUnit.Minutes)\">\r\n    </div>\r\n\r\n    <button type=\"button\"\r\n            class=\"spinner display-flex justify-center align-items-center\"\r\n            (click)=\"decrement(timeUnit.Minutes)\">\r\n      <i class=\"fas fa-chevron-down\" aria-hidden=\"true\"></i>\r\n    </button>\r\n  </div>\r\n\r\n  <div *ngIf=\"isMeridiem\"\r\n        class=\"time-unit\">\r\n    <button type=\"button\"\r\n            class=\"display-flex justify-center align-items-center\"\r\n            (click)=\"changeNoonRelativity()\">\r\n      <span class=\"meridiem\">\r\n        {{noonRelativity.toUpperCase()}}\r\n      </span>\r\n      <i class=\"far fa-clock meridiem-icon\" aria-hidden=\"true\"></i>\r\n    </button>\r\n  </div>\r\n</div>\r\n", styles: [".sq .time-picker{border-top:1px solid rgba(46,159,134,.69);border-bottom:1px solid rgba(46,159,134,.69);font-size:23px}.sq .time-picker input{background-color:#127d681f;border:none;width:38px;height:38px;text-align:center}.sq .time-picker .time{padding:5px 0 3px}.sq .time-picker .time-unit{padding:7px 0 10px}.sq .time-picker .time-unit:not(:last-child){margin-right:15px}.sq .time-picker .time-unit .spinner,.sq .time-picker .time-unit .meridiem-icon{opacity:0;pointer-events:none;transition:.3s all ease-in}.sq .time-picker .time-unit .spinner{height:25px}.sq .time-picker .time-unit:hover .spinner,.sq .time-picker .time-unit:hover .meridiem-icon{opacity:1;pointer-events:auto}.sq .time-picker .time-unit .far{font-size:18px}.sq .time-picker .meridiem{padding-right:5px}.sq .time-picker .divider{font-size:44px;margin-bottom:7px}\n"], dependencies: [{ kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2$1.MinLengthValidator, selector: "[minlength][formControlName],[minlength][formControl],[minlength][ngModel]", inputs: ["minlength"] }, { kind: "directive", type: i2$1.MaxLengthValidator, selector: "[maxlength][formControlName],[maxlength][formControl],[maxlength][ngModel]", inputs: ["maxlength"] }, { kind: "directive", type: i2$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: TimePickerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sq-time-picker', encapsulation: ViewEncapsulation.None, providers: [CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR$1], template: "<div class=\"time-picker display-flex justify-center align-items-center\">\r\n  <div class=\"time-unit display-flex column align-items-center\">\r\n    <button type=\"button\"\r\n            class=\"spinner display-flex justify-center align-items-center\"\r\n            (click)=\"increment(timeUnit.Hours)\">\r\n      <i class=\"fas fa-chevron-up\" aria-hidden=\"true\"></i>\r\n    </button>\r\n\r\n    <div class=\"time display-flex column align-items-center\">\r\n      <input type=\"text\"\r\n             name=\"time\"\r\n             [(ngModel)]=\"hours\"\r\n             maxlength=\"2\"\r\n             minlength=\"1\"\r\n             [disabled]=\"!isEditable\"\r\n             [ngModelOptions]=\"{standalone: true}\"\r\n             (ngModelChange)=\"validateInput(timeUnit.Hours)\">\r\n    </div>\r\n\r\n    <button type=\"button\"\r\n            class=\"spinner display-flex justify-center align-items-center\"\r\n            (click)=\"decrement(timeUnit.Hours)\">\r\n      <i class=\"fas fa-chevron-down\" aria-hidden=\"true\"></i>\r\n    </button>\r\n  </div>\r\n\r\n  <div class=\"time-unit divider\">:</div>\r\n\r\n  <div class=\"time-unit display-flex column align-items-center\">\r\n    <button type=\"button\"\r\n            class=\"spinner display-flex justify-center align-items-center\"\r\n            (click)=\"increment(timeUnit.Minutes)\">\r\n      <i class=\"fas fa-chevron-up\" aria-hidden=\"true\"></i>\r\n    </button>\r\n\r\n    <div class=\"time\">\r\n      <input type=\"text\"\r\n             name=\"minutes\"\r\n             [(ngModel)]=\"minutes\"\r\n             maxlength=\"2\"\r\n             minlength=\"1\"\r\n             [disabled]=\"!isEditable\"\r\n             [ngModelOptions]=\"{standalone: true}\"\r\n             (ngModelChange)=\"validateInput(timeUnit.Minutes)\">\r\n    </div>\r\n\r\n    <button type=\"button\"\r\n            class=\"spinner display-flex justify-center align-items-center\"\r\n            (click)=\"decrement(timeUnit.Minutes)\">\r\n      <i class=\"fas fa-chevron-down\" aria-hidden=\"true\"></i>\r\n    </button>\r\n  </div>\r\n\r\n  <div *ngIf=\"isMeridiem\"\r\n        class=\"time-unit\">\r\n    <button type=\"button\"\r\n            class=\"display-flex justify-center align-items-center\"\r\n            (click)=\"changeNoonRelativity()\">\r\n      <span class=\"meridiem\">\r\n        {{noonRelativity.toUpperCase()}}\r\n      </span>\r\n      <i class=\"far fa-clock meridiem-icon\" aria-hidden=\"true\"></i>\r\n    </button>\r\n  </div>\r\n</div>\r\n", styles: [".sq .time-picker{border-top:1px solid rgba(46,159,134,.69);border-bottom:1px solid rgba(46,159,134,.69);font-size:23px}.sq .time-picker input{background-color:#127d681f;border:none;width:38px;height:38px;text-align:center}.sq .time-picker .time{padding:5px 0 3px}.sq .time-picker .time-unit{padding:7px 0 10px}.sq .time-picker .time-unit:not(:last-child){margin-right:15px}.sq .time-picker .time-unit .spinner,.sq .time-picker .time-unit .meridiem-icon{opacity:0;pointer-events:none;transition:.3s all ease-in}.sq .time-picker .time-unit .spinner{height:25px}.sq .time-picker .time-unit:hover .spinner,.sq .time-picker .time-unit:hover .meridiem-icon{opacity:1;pointer-events:auto}.sq .time-picker .time-unit .far{font-size:18px}.sq .time-picker .meridiem{padding-right:5px}.sq .time-picker .divider{font-size:44px;margin-bottom:7px}\n"] }]
        }], ctorParameters: function () { return []; }, propDecorators: { hourStep: [{
                type: Input
            }], minuteStep: [{
                type: Input
            }], isMeridiem: [{
                type: Input
            }], isEditable: [{
                type: Input
            }], inputHours: [{
                type: Input,
                args: ['hours']
            }], inputMinutes: [{
                type: Input,
                args: ['minutes']
            }], timeObjectType: [{
                type: Input
            }], inputHoursChange: [{
                type: Output,
                args: ['hoursChange']
            }], inputMinutesChange: [{
                type: Output,
                args: ['minutesChange']
            }] } });

const CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => DatetimePickerComponent),
    multi: true
};
class DatetimePickerComponent extends InputCoreComponent {
    constructor(calendarManager) {
        super();
        this.calendarManager = calendarManager;
        this.locale = 'en';
        this.isMultipleSelect = false;
        this.isTimepickerEnabled = false;
        this.dateObjectType = DateObjectType.Moment;
        this.dateSelectionChange = new EventEmitter();
        this.isMonthsPickerEnabled = false;
        this.isYearsPickerEnabled = false;
        this.calendarPeriodRelativity = CalendarPeriodRelativityEnum;
        this.period = CalendarPeriodTypeEnum.Month;
        this.selectedDates = List();
    }
    ngOnInit() {
        moment.locale(this.locale);
        this.calendarManager.setLocale(this.locale);
        const now = moment().hours(0).minutes(0).locale(this.locale);
        this.selectedDates = List([now.clone()]);
        this.weekdays = this.calendarManager.getWeekdays();
        this.calendar = this.getMonthCalendar(now.clone());
    }
    ngAfterViewInit() {
        setTimeout(() => {
            this.setValueResult();
        });
    }
    ngOnChanges(changesObj) {
        if (changesObj.timepickerConfig && changesObj.timepickerConfig.currentValue) {
            this.setValueResult();
        }
    }
    writeValue(newValue) {
        super.writeValue(newValue);
        if (this.selectedDates.size === 1 && this.selectedDates.get(0).isSame(moment(), 'day')) {
            if (newValue) {
                this.deselectAll();
                if (Array.isArray(newValue)) {
                    newValue.forEach((date) => {
                        if (!this.currentMonth.isSame(moment(date), 'month')) {
                            this.calendar = this.getMonthCalendar(moment(date));
                        }
                        const convertedDate = this.calendarManager.findADateFromCalendar(moment(date), this.calendar);
                        this.markDateAsSelected(convertedDate);
                    });
                }
                else {
                    if (!this.currentMonth.isSame(moment(newValue), 'month')) {
                        this.calendar = this.getMonthCalendar(moment(newValue));
                    }
                    const calendarDay = this.calendarManager.findADateFromCalendar(moment(newValue), this.calendar);
                    this.markDateAsSelected(calendarDay);
                }
            }
        }
    }
    onDateClick(date) {
        switch (date.relativityToCurrentMonth) {
            case CalendarPeriodRelativityEnum.After:
                this.select(date);
                this.next();
                break;
            case CalendarPeriodRelativityEnum.Before:
                this.select(date);
                this.previous();
                break;
            default:
                this.select(date);
                break;
        }
    }
    select(date) {
        const month = this.currentMonth.clone();
        if (date.relativityToCurrentMonth === CalendarPeriodRelativityEnum.Before) {
            month.subtract(1, 'month');
        }
        if (date.relativityToCurrentMonth === CalendarPeriodRelativityEnum.After) {
            month.add(1, 'month');
        }
        this.markDateAsSelected(date);
        this.dateSelectionChange.emit(this.value);
    }
    next() {
        if (this.period === CalendarPeriodTypeEnum.Month) {
            const nextMonth = this.currentMonth.add(1, 'month');
            this.calendar = this.getMonthCalendar(nextMonth);
        }
        if (this.period === CalendarPeriodTypeEnum.Year) {
            const dateRange = {
                minDate: moment(this.minDate),
                maxDate: moment(this.maxDate)
            };
            this.yearsList = this.calendarManager.generateYearPickerCollection(null, 19, dateRange);
        }
    }
    previous() {
        if (this.period === CalendarPeriodTypeEnum.Month) {
            const previousMonth = this.currentMonth.subtract(1, 'month');
            this.calendar = this.getMonthCalendar(previousMonth);
        }
        if (this.period === CalendarPeriodTypeEnum.Year) {
            const dateRange = {
                minDate: moment(this.minDate),
                maxDate: moment(this.maxDate)
            };
            this.yearsList = this.calendarManager.generateYearPickerCollection(null, -19, dateRange);
        }
    }
    getMonthCalendar(startPeriod) {
        const selectedDates = this.selectedDates.toArray();
        const dateRange = {
            minDate: this.minDate,
            maxDate: this.maxDate
        };
        this.currentMonth = startPeriod.clone();
        return this.calendarManager.generateCalendarForMonth(startPeriod, this.currentMonth, selectedDates, dateRange);
    }
    showMonthsPicker(year = this.currentMonth.year()) {
        this.deselectAll();
        this.isYearsPickerEnabled = false;
        this.isMonthsPickerEnabled = true;
        this.currentMonth.year(year);
        const dateRange = {
            minDate: this.minDate,
            maxDate: this.maxDate
        };
        this.period = CalendarPeriodTypeEnum.Month;
        this.months = this.calendarManager.generateMonthPickerCollection(year, dateRange);
    }
    showYearsPicker() {
        this.deselectAll();
        this.isMonthsPickerEnabled = false;
        this.isYearsPickerEnabled = true;
        const dateRange = {
            minDate: this.minDate,
            maxDate: this.maxDate
        };
        this.period = CalendarPeriodTypeEnum.Year;
        this.yearsList = this.calendarManager.generateYearPickerCollection(this.currentMonth, 19, dateRange);
    }
    selectMonth(month) {
        this.calendar = this.getMonthCalendar(month.momentObj);
        this.isMonthsPickerEnabled = false;
    }
    selectYear(year) {
        this.showMonthsPicker(year.momentObj.year());
    }
    onTimeChange() {
        this.setValueResult();
        this.dateSelectionChange.emit(this.value);
    }
    markDateAsSelected(date) {
        const selectedMomentObj = moment(date.momentObj);
        const selectedIndex = this.calendarManager.getSelectedItemIndex(selectedMomentObj, this.selectedDates.toArray());
        if (this.isMultipleSelect) {
            if (selectedIndex > -1) {
                date.isSelected = false;
                this.selectedDates = this.selectedDates.remove(selectedIndex);
            }
            else {
                this.selectedDates = this.selectedDates.push(selectedMomentObj);
                date.isSelected = true;
            }
        }
        else {
            const previousDate = this.calendarManager.findADateFromCalendar(this.selectedDates.get(0), this.calendar);
            if (previousDate) {
                previousDate.isSelected = false;
            }
            this.selectedDates = this.selectedDates.clear();
            this.selectedDates = this.selectedDates.push(selectedMomentObj);
            date.isSelected = true;
        }
        this.setValueResult();
    }
    deselectAll() {
        this.selectedDates.toArray().forEach((selectedDate) => {
            const calendarDay = this.calendarManager.findADateFromCalendar(selectedDate, this.calendar);
            // this handles the case when we have a selected date
            // from the previous month but we haven't selected anything
            // from the current
            if (calendarDay) {
                calendarDay.isSelected = false;
            }
        });
        this.selectedDates = List([]);
        this.setValueResult();
    }
    setValueResult() {
        this.parsedSelectedDates = this.selectedDates.toArray();
        if (this.parsedSelectedDates.length > 0) {
            this.setValueTimeIfNeeded();
            this.sortValueIfNeeded();
            this.toValueDateObjectTypeIfNeeded();
            this.toValueFormatIfNeeded();
        }
        if (this.isMultipleSelect) {
            this.value = this.parsedSelectedDates;
        }
        else {
            this.value = this.parsedSelectedDates[0];
        }
    }
    toValueDateObjectTypeIfNeeded() {
        if (!this.format) {
            switch (this.dateObjectType) {
                case DateObjectType.Date:
                    this.parsedSelectedDates = this.parsedSelectedDates.map((momentObj) => {
                        return momentObj.toDate();
                    });
                    break;
                case DateObjectType.Unix:
                    this.parsedSelectedDates = this.parsedSelectedDates.map((momentObj) => {
                        return momentObj.toDate().getTime();
                    });
                    break;
            }
        }
    }
    toValueFormatIfNeeded() {
        if (this.format) {
            const formattedDates = this.parsedSelectedDates.map((date) => {
                return moment(date).format(this.format);
            });
            this.parsedSelectedDates = formattedDates;
        }
    }
    setValueTimeIfNeeded() {
        if (this.isTimepickerEnabled && this.time) {
            const datesWithTime = this.parsedSelectedDates.map((momentObj) => {
                return momentObj.hours(this.time.hours()).minutes(this.time.minutes());
            });
            this.parsedSelectedDates = datesWithTime;
        }
    }
    sortValueIfNeeded() {
        if (this.isMultipleSelect) {
            const sortedDates = this.calendarManager.sortDatesAsc(this.parsedSelectedDates);
            this.parsedSelectedDates = sortedDates;
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: DatetimePickerComponent, deps: [{ token: CalendarManagerService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.0.4", type: DatetimePickerComponent, selector: "sq-datetime-picker", inputs: { locale: "locale", maxDate: "maxDate", minDate: "minDate", isMultipleSelect: "isMultipleSelect", format: "format", isTimepickerEnabled: "isTimepickerEnabled", dateObjectType: "dateObjectType", timepickerConfig: "timepickerConfig" }, outputs: { dateSelectionChange: "dateSelectionChange" }, providers: [CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR], usesInheritance: true, usesOnChanges: true, ngImport: i0, template: "<div class=\"datetime-picker-wrapper\">\r\n  <div class=\"period-section display-flex\"\r\n       [ngClass]=\"{'justify-center': isMonthsPickerEnabled,\r\n                   'space-between': !isMonthsPickerEnabled}\">\r\n    <button type=\"button\"\r\n            (click)=\"previous()\"\r\n            class=\"change-period prev\"\r\n            *ngIf=\"!isMonthsPickerEnabled\">\r\n      <i class=\"fas fa-chevron-left\"></i>\r\n    </button>\r\n\r\n    <div>\r\n      <button type=\"button\"\r\n              class=\"month-name\"\r\n              (click)=\"showMonthsPicker()\"\r\n              *ngIf=\"!isMonthsPickerEnabled && !isYearsPickerEnabled\">\r\n        <strong class=\"period-name\">{{ currentMonth.format('MMMM') }}</strong>\r\n      </button>\r\n\r\n      <button type=\"button\"\r\n              (click)=\"showYearsPicker()\"\r\n              *ngIf=\"!isYearsPickerEnabled\">\r\n        <strong class=\"period-name\">{{ currentMonth.format('YYYY') }}</strong>\r\n      </button>\r\n\r\n      <strong class=\"period-name\" *ngIf=\"isYearsPickerEnabled\">\r\n        {{ yearsList[0].displayName + ' - ' + yearsList[yearsList.length - 1].displayName }}\r\n      </strong>\r\n    </div>\r\n\r\n    <button type=\"button\"\r\n            (click)=\"next()\"\r\n            class=\"change-period next\"\r\n            *ngIf=\"!isMonthsPickerEnabled\">\r\n      <i class=\"fas fa-chevron-right\"></i>\r\n    </button>\r\n  </div>\r\n\r\n  <div class=\"alt-picker display-flex space-between wrap\"\r\n       *ngIf=\"isMonthsPickerEnabled || isYearsPickerEnabled\">\r\n    <ng-template [ngIf]=\"isMonthsPickerEnabled\">\r\n      <button type=\"button\"\r\n              class=\"picker-item\"\r\n              *ngFor=\"let month of months\"\r\n              (click)=\"selectMonth(month)\"\r\n              [ngClass]=\"{'disabled': month.isDisabled}\">\r\n        {{ month.displayName }}\r\n      </button>\r\n    </ng-template>\r\n\r\n    <ng-template [ngIf]=\"isYearsPickerEnabled\">\r\n      <button type=\"button\"\r\n              class=\"picker-item\"\r\n              *ngFor=\"let year of yearsList\"\r\n              (click)=\"selectYear(year)\"\r\n              [ngClass]=\"{'disabled': year.isDisabled}\">\r\n        {{ year.displayName }}\r\n      </button>\r\n    </ng-template>\r\n  </div>\r\n\r\n  <table class=\"datetime-picker\" *ngIf=\"!isMonthsPickerEnabled && !isYearsPickerEnabled\">\r\n    <thead>\r\n      <tr>\r\n        <th *ngFor=\"let day of weekdays\" class=\"heading\">\r\n          <span class=\"text\">{{ day }}</span>\r\n        </th>\r\n      </tr>\r\n    </thead>\r\n    <tbody>\r\n      <tr *ngFor=\"let dateRow of calendar\" class=\"row\">\r\n        <td *ngFor=\"let date of dateRow\"\r\n            class=\"cell\"\r\n            (click)=\"onDateClick(date)\"\r\n            [ngClass]=\"{'beyond-current-period': date.relativityToCurrentMonth !== calendarPeriodRelativity.Current,\r\n                        'selected': date.isSelected,\r\n                        'disabled': date.isDisabled}\">\r\n          {{ date.displayDate }}\r\n        </td>\r\n      </tr>\r\n    </tbody>\r\n  </table>\r\n\r\n  <sq-time-picker *ngIf=\"isTimepickerEnabled\"\r\n                  [(ngModel)]=\"time\"\r\n                  (ngModelChange)=\"onTimeChange()\"\r\n                  [ngModelOptions]=\"{standalone: true}\"\r\n                  timeObjectType=\"moment\"\r\n                  [hours]=\"timepickerConfig.hours\"\r\n                  [minutes]=\"timepickerConfig.minutes\"\r\n                  [hourStep]=\"timepickerConfig.hourStep\"\r\n                  [minuteStep]=\"timepickerConfig.minuteStep\"\r\n                  [isEditable]=\"timepickerConfig.isEditable\"\r\n                  [isMeridiem]=\"timepickerConfig.isMeridiem\">\r\n  </sq-time-picker>\r\n</div>\r\n", styles: [".sq .datetime-picker-wrapper{max-width:410px;font-size:14px}.sq .datetime-picker-wrapper .picker-item{font-size:19px;background-color:#e2efed;padding:5px 12px;text-transform:uppercase;cursor:pointer;margin-left:5px;margin-right:5px;margin-bottom:10px;min-width:80px;text-align:center}.sq .datetime-picker-wrapper .picker-item.disabled{background-color:#4c4c4c1f;pointer-events:none}.sq .period-section{align-items:center;padding-bottom:12px;text-transform:uppercase;border-bottom:1px solid rgba(46,159,134,.69)}.sq .period-name{font-size:20px;text-transform:uppercase}.sq .month-name{margin-right:10px}.sq .change-period{font-size:18px}.sq .change-period.next{padding-left:20px}.sq .change-period.prev{padding-right:20px}.sq .alt-picker{padding-top:10px}.sq .datetime-picker{width:100%;text-align:center;table-layout:fixed;border-collapse:collapse;border:none}.sq .datetime-picker .heading{width:14%;padding:10px 17px;background-color:#127d684d;text-transform:uppercase;border-bottom:1px solid rgba(46,159,134,.69)}.sq .datetime-picker .heading:last-child{border-right:none}.sq .datetime-picker .cell{cursor:default;padding:6px 20px;transition:.1s background-color cubic-bezier(.55,.09,.68,.53)}.sq .datetime-picker .cell.beyond-current-period{color:#2e9f86}.sq .datetime-picker .cell.selected{font-weight:700;background-color:#b7d8d1}.sq .datetime-picker .cell.disabled{pointer-events:none;color:#aba9a9}.sq .datetime-picker .row:nth-child(2n) .cell{background-color:#127d681f}.sq .datetime-picker .row:nth-child(2n) .cell.selected{background-color:#b7d8d1}@media (max-width: 450px){.sq .datetime-picker .heading{padding:10px 15px}.sq .datetime-picker .heading .text{display:inline-block;visibility:hidden}.sq .datetime-picker .heading .text:first-letter{visibility:visible}.sq .datetime-picker .cell{padding:6px 12px}}\n"], dependencies: [{ kind: "directive", type: i2.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }, { kind: "directive", type: i2.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i2.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i2$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: TimePickerComponent, selector: "sq-time-picker", inputs: ["hourStep", "minuteStep", "isMeridiem", "isEditable", "hours", "minutes", "timeObjectType"], outputs: ["hoursChange", "minutesChange"] }], encapsulation: i0.ViewEncapsulation.None }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: DatetimePickerComponent, decorators: [{
            type: Component,
            args: [{ selector: 'sq-datetime-picker', encapsulation: ViewEncapsulation.None, providers: [CUSTOM_INPUT_CONTROL_VALUE_ACCESSOR], template: "<div class=\"datetime-picker-wrapper\">\r\n  <div class=\"period-section display-flex\"\r\n       [ngClass]=\"{'justify-center': isMonthsPickerEnabled,\r\n                   'space-between': !isMonthsPickerEnabled}\">\r\n    <button type=\"button\"\r\n            (click)=\"previous()\"\r\n            class=\"change-period prev\"\r\n            *ngIf=\"!isMonthsPickerEnabled\">\r\n      <i class=\"fas fa-chevron-left\"></i>\r\n    </button>\r\n\r\n    <div>\r\n      <button type=\"button\"\r\n              class=\"month-name\"\r\n              (click)=\"showMonthsPicker()\"\r\n              *ngIf=\"!isMonthsPickerEnabled && !isYearsPickerEnabled\">\r\n        <strong class=\"period-name\">{{ currentMonth.format('MMMM') }}</strong>\r\n      </button>\r\n\r\n      <button type=\"button\"\r\n              (click)=\"showYearsPicker()\"\r\n              *ngIf=\"!isYearsPickerEnabled\">\r\n        <strong class=\"period-name\">{{ currentMonth.format('YYYY') }}</strong>\r\n      </button>\r\n\r\n      <strong class=\"period-name\" *ngIf=\"isYearsPickerEnabled\">\r\n        {{ yearsList[0].displayName + ' - ' + yearsList[yearsList.length - 1].displayName }}\r\n      </strong>\r\n    </div>\r\n\r\n    <button type=\"button\"\r\n            (click)=\"next()\"\r\n            class=\"change-period next\"\r\n            *ngIf=\"!isMonthsPickerEnabled\">\r\n      <i class=\"fas fa-chevron-right\"></i>\r\n    </button>\r\n  </div>\r\n\r\n  <div class=\"alt-picker display-flex space-between wrap\"\r\n       *ngIf=\"isMonthsPickerEnabled || isYearsPickerEnabled\">\r\n    <ng-template [ngIf]=\"isMonthsPickerEnabled\">\r\n      <button type=\"button\"\r\n              class=\"picker-item\"\r\n              *ngFor=\"let month of months\"\r\n              (click)=\"selectMonth(month)\"\r\n              [ngClass]=\"{'disabled': month.isDisabled}\">\r\n        {{ month.displayName }}\r\n      </button>\r\n    </ng-template>\r\n\r\n    <ng-template [ngIf]=\"isYearsPickerEnabled\">\r\n      <button type=\"button\"\r\n              class=\"picker-item\"\r\n              *ngFor=\"let year of yearsList\"\r\n              (click)=\"selectYear(year)\"\r\n              [ngClass]=\"{'disabled': year.isDisabled}\">\r\n        {{ year.displayName }}\r\n      </button>\r\n    </ng-template>\r\n  </div>\r\n\r\n  <table class=\"datetime-picker\" *ngIf=\"!isMonthsPickerEnabled && !isYearsPickerEnabled\">\r\n    <thead>\r\n      <tr>\r\n        <th *ngFor=\"let day of weekdays\" class=\"heading\">\r\n          <span class=\"text\">{{ day }}</span>\r\n        </th>\r\n      </tr>\r\n    </thead>\r\n    <tbody>\r\n      <tr *ngFor=\"let dateRow of calendar\" class=\"row\">\r\n        <td *ngFor=\"let date of dateRow\"\r\n            class=\"cell\"\r\n            (click)=\"onDateClick(date)\"\r\n            [ngClass]=\"{'beyond-current-period': date.relativityToCurrentMonth !== calendarPeriodRelativity.Current,\r\n                        'selected': date.isSelected,\r\n                        'disabled': date.isDisabled}\">\r\n          {{ date.displayDate }}\r\n        </td>\r\n      </tr>\r\n    </tbody>\r\n  </table>\r\n\r\n  <sq-time-picker *ngIf=\"isTimepickerEnabled\"\r\n                  [(ngModel)]=\"time\"\r\n                  (ngModelChange)=\"onTimeChange()\"\r\n                  [ngModelOptions]=\"{standalone: true}\"\r\n                  timeObjectType=\"moment\"\r\n                  [hours]=\"timepickerConfig.hours\"\r\n                  [minutes]=\"timepickerConfig.minutes\"\r\n                  [hourStep]=\"timepickerConfig.hourStep\"\r\n                  [minuteStep]=\"timepickerConfig.minuteStep\"\r\n                  [isEditable]=\"timepickerConfig.isEditable\"\r\n                  [isMeridiem]=\"timepickerConfig.isMeridiem\">\r\n  </sq-time-picker>\r\n</div>\r\n", styles: [".sq .datetime-picker-wrapper{max-width:410px;font-size:14px}.sq .datetime-picker-wrapper .picker-item{font-size:19px;background-color:#e2efed;padding:5px 12px;text-transform:uppercase;cursor:pointer;margin-left:5px;margin-right:5px;margin-bottom:10px;min-width:80px;text-align:center}.sq .datetime-picker-wrapper .picker-item.disabled{background-color:#4c4c4c1f;pointer-events:none}.sq .period-section{align-items:center;padding-bottom:12px;text-transform:uppercase;border-bottom:1px solid rgba(46,159,134,.69)}.sq .period-name{font-size:20px;text-transform:uppercase}.sq .month-name{margin-right:10px}.sq .change-period{font-size:18px}.sq .change-period.next{padding-left:20px}.sq .change-period.prev{padding-right:20px}.sq .alt-picker{padding-top:10px}.sq .datetime-picker{width:100%;text-align:center;table-layout:fixed;border-collapse:collapse;border:none}.sq .datetime-picker .heading{width:14%;padding:10px 17px;background-color:#127d684d;text-transform:uppercase;border-bottom:1px solid rgba(46,159,134,.69)}.sq .datetime-picker .heading:last-child{border-right:none}.sq .datetime-picker .cell{cursor:default;padding:6px 20px;transition:.1s background-color cubic-bezier(.55,.09,.68,.53)}.sq .datetime-picker .cell.beyond-current-period{color:#2e9f86}.sq .datetime-picker .cell.selected{font-weight:700;background-color:#b7d8d1}.sq .datetime-picker .cell.disabled{pointer-events:none;color:#aba9a9}.sq .datetime-picker .row:nth-child(2n) .cell{background-color:#127d681f}.sq .datetime-picker .row:nth-child(2n) .cell.selected{background-color:#b7d8d1}@media (max-width: 450px){.sq .datetime-picker .heading{padding:10px 15px}.sq .datetime-picker .heading .text{display:inline-block;visibility:hidden}.sq .datetime-picker .heading .text:first-letter{visibility:visible}.sq .datetime-picker .cell{padding:6px 12px}}\n"] }]
        }], ctorParameters: function () { return [{ type: CalendarManagerService }]; }, propDecorators: { locale: [{
                type: Input
            }], maxDate: [{
                type: Input
            }], minDate: [{
                type: Input
            }], isMultipleSelect: [{
                type: Input
            }], format: [{
                type: Input
            }], isTimepickerEnabled: [{
                type: Input
            }], dateObjectType: [{
                type: Input
            }], timepickerConfig: [{
                type: Input
            }], dateSelectionChange: [{
                type: Output
            }] } });

class DatetimePickerModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: DatetimePickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.0.4", ngImport: i0, type: DatetimePickerModule, declarations: [TimePickerComponent,
            DatetimePickerComponent], imports: [CommonModule,
            FormsModule], exports: [TimePickerComponent,
            DatetimePickerComponent] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: DatetimePickerModule, providers: [CalendarManagerService], imports: [CommonModule,
            FormsModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: DatetimePickerModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        CommonModule,
                        FormsModule
                    ],
                    declarations: [
                        TimePickerComponent,
                        DatetimePickerComponent
                    ],
                    exports: [
                        TimePickerComponent,
                        DatetimePickerComponent
                    ],
                    providers: [CalendarManagerService],
                    schemas: [CUSTOM_ELEMENTS_SCHEMA, NO_ERRORS_SCHEMA]
                }]
        }] });

class NgDatetimePickerModule {
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: NgDatetimePickerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule }); }
    static { this.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.0.4", ngImport: i0, type: NgDatetimePickerModule, imports: [DatetimePickerModule], exports: [DatetimePickerModule] }); }
    static { this.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: NgDatetimePickerModule, imports: [DatetimePickerModule, DatetimePickerModule] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.0.4", ngImport: i0, type: NgDatetimePickerModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        DatetimePickerModule
                    ],
                    declarations: [],
                    exports: [DatetimePickerModule]
                }]
        }] });

/*
 * Public API Surface of ng-datetime-picker
 */

/**
 * Generated bundle index. Do not edit.
 */

export { DatetimePickerComponent, DatetimePickerModule, NgDatetimePickerModule, TimePickerComponent };
//# sourceMappingURL=sq-ui-ng-datetime-picker.mjs.map
